package de.deversmann.domain;

import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

public class CSVReader {

    public PuzzleData readPuzzleWithSolution(String csvFile) throws IOException {
        List<int[]> puzzleRows = new ArrayList<>();
        List<int[]> solutionCoordinates = new ArrayList<>();

        try (BufferedReader br = new BufferedReader(new FileReader(csvFile))) {
            String line;
            boolean inSolutionPart = false;

            while ((line = br.readLine()) != null) {
                line = line.trim();
                if (line.isEmpty()) {
                    continue;
                }
                if (line.startsWith("//Lösung") || line.startsWith("//")) {
                    inSolutionPart = true;
                    continue;
                }

                if (!inSolutionPart) {
                    // Puzzle-Teil
                    String[] tokens = line.split(",");
                    int[] rowValues = new int[tokens.length];
                    for (int i = 0; i < tokens.length; i++) {
                        rowValues[i] = Integer.parseInt(tokens[i].trim());
                    }
                    puzzleRows.add(rowValues);
                } else {
                    // Lösungsteil
                    String[] coords = line.split(",");
                    if (coords.length == 2) {
                        int row = Integer.parseInt(coords[0].trim());
                        int col = Integer.parseInt(coords[1].trim());
                        solutionCoordinates.add(new int[]{row, col});
                    }
                }
            }
        }

        // puzzleRows -> 2D-Array
        int[][] puzzleArray = new int[puzzleRows.size()][];
        for (int i = 0; i < puzzleRows.size(); i++) {
            puzzleArray[i] = puzzleRows.get(i);
        }

        return new PuzzleData(puzzleArray, solutionCoordinates);
    }
}