package de.deversmann.domain;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.IOException;
import java.util.Random;

public class Spielfeld {

    private int[][] feld;
    private String[][] zustand; // "grau", "schwarz", "weiß"

    public Spielfeld() {
    }

    public void ladeSpielfeld(String dateiPfad) {
        try (BufferedReader br = new BufferedReader(new FileReader(dateiPfad))) {
            String line;
            int zeilenZaehler = 0;


            while ((line = br.readLine()) != null) {
                zeilenZaehler++;
            }

            br.close();

            feld = new int[zeilenZaehler][];
            zustand = new String[zeilenZaehler][];

            try (BufferedReader br2 = new BufferedReader(new FileReader(dateiPfad))) {
                int row = 0;
                while ((line = br2.readLine()) != null) {
                    String[] werte = line.split(",");
                    feld[row] = new int[werte.length];
                    zustand[row] = new String[werte.length];

                    for (int col = 0; col < werte.length; col++) {
                        feld[row][col] = Integer.parseInt(werte[col]);
                        zustand[row][col] = "grau";
                    }

                    row++;
                }
            }
        } catch (IOException e) {
            System.err.println("Fehler beim Laden des Spielfelds: " + e.getMessage());
        }
    }

    public void ladeZufaelligesSpielfeld(String ordnerPfad) {
        File ordner = new File(ordnerPfad);
        File[] dateien = ordner.listFiles((dir, name) -> name.endsWith(".csv"));

        if (dateien != null && dateien.length > 0) {
            Random random = new Random();
            File zufallsDatei = dateien[random.nextInt(dateien.length)];
            ladeSpielfeld(zufallsDatei.getAbsolutePath());
        } else {
            System.err.println("Keine CSV-Dateien im Verzeichnis gefunden!");
        }
    }

    public void setzeZustand(int x, int y, String neuerZustand) {
        if (istImBereich(x, y)) {
            zustand[x][y] = neuerZustand;
        } else {
            System.err.println("Koordinaten außerhalb des Spielfelds!");
        }
    }

    public String getZustand(int x, int y) {
        if (istImBereich(x, y)) {
            return zustand[x][y];
        } else {
            System.err.println("Koordinaten außerhalb des Spielfelds!");
            return null;
        }
    }

    public int getWert(int x, int y) {
        if (istImBereich(x, y)) {
            return feld[x][y];
        } else {
            System.err.println("Koordinaten außerhalb des Spielfelds!");
            return -1;
        }
    }

    public void reset() {
        for (int i = 0; i < zustand.length; i++) {
            for (int j = 0; j < zustand[i].length; j++) {
                zustand[i][j] = "grau";
            }
        }
    }

    public int getBreite() {
        return feld[0].length;
    }

    public int getHoehe() {
        return feld.length;
    }

    private boolean istImBereich(int x, int y) {
        return x >= 0 && x < feld.length && y >= 0 && y < feld[0].length;
    }
}
